# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.126
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.participant_dashboard_nomination_options import ParticipantDashboardNominationOptions  # noqa: E501

class TestParticipantDashboardNominationOptions(unittest.TestCase):
    """ParticipantDashboardNominationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardNominationOptions:
        """Test ParticipantDashboardNominationOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNominationOptions`
        """
        model = ParticipantDashboardNominationOptions()  # noqa: E501
        if include_optional:
            return ParticipantDashboardNominationOptions(
                long_term = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], ),
                day_ahead = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], ),
                intra_day = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], )
            )
        else:
            return ParticipantDashboardNominationOptions(
                long_term = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], ),
                day_ahead = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], ),
                intra_day = helix_platform_api_public_client.models.participant_dashboard_nomination_options_timescale.ParticipantDashboardNominationOptionsTimescale(
                    delivery_days = [
                        'Tue Jan 04 00:00:00 UTC 2022'
                        ], 
                    available = True, 
                    tr_directions = [
                        'GB_FR'
                        ], ),
        )
        """

    def testParticipantDashboardNominationOptions(self):
        """Test ParticipantDashboardNominationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
